collect_modifier_guards

Function collect_modifier_guards 

fn collect_modifier_guards(
    hir: &Hir<'_>,
    invocation: &Modifier<'_>,
    caller_params: &HashSet<VariableId>,
    guarded: &mut HashSet<VariableId>,
)
Maps each direct-ident modifier argument back to its caller-side parameter, runs the same guard analysis on the modifier body, and records any caller params whose mapped modifier parameter is guarded.