fn collect_modifier_guards(
hir: &Hir<'_>,
invocation: &Modifier<'_>,
caller_params: &HashSet<VariableId>,
guarded: &mut HashSet<VariableId>,
)Expand description
Maps each direct-ident modifier argument back to its caller-side parameter, runs the same guard analysis on the modifier body, and records any caller params whose mapped modifier parameter is guarded.